==> astro-0.0.7.tgz: package/lib/frontend/render/utils.js <==
import unified from 'unified';
import parse from 'rehype-parse';
import toH from 'hast-to-hyperscript';
import moize from 'moize';
/** @internal */
function childrenToTree(children) {
    return children.map((child) => unified().use(parse, { fragment: true }).parse(child).children.pop());
}
/**
 * Converts an HTML fragment string into vnodes for rendering via provided framework
 * @param h framework's `createElement` function
 * @param children the HTML string children
 */
export const childrenToVnodes = moize.deep(function childrenToVnodes(h, children) {
    const tree = childrenToTree(children);
    const vnodes = tree.map((subtree) => toH(h, subtree));
    return vnodes;
});
/**
 * Converts an HTML fragment string into h function calls as a string
 * @param h framework's `createElement` function
 * @param children the HTML string children
 */
export const childrenToH = moize.deep(function childrenToH(renderer, children) {
    if (!renderer.jsxPragma)
        return;
    const tree = childrenToTree(children);
    const innerH = (name, attrs = null, _children = null) => {
        const vnode = renderer.jsxPragma?.(name, attrs, _children);
        const childStr = _children ? `, [${_children.map((child) => serializeChild(child)).join(',')}]` : '';
        /* fix(react): avoid hard-coding keys into the serialized tree */
        if (attrs && attrs.key)
            attrs.key = undefined;
        const __SERIALIZED = `${renderer.jsxPragmaName}("${name}", ${attrs ? JSON.stringify(attrs) : 'null'}${childStr})`;
        return { ...vnode, __SERIALIZED };
    };
    const serializeChild = (child) => {
        if (typeof child === 'string')
            return `\`${child}\``;
        if (typeof child === 'number' || typeof child === 'boolean')
            return `${child}`;
        if (child === null)
            return `null`;
        if (child.__SERIALIZED)
            return child.__SERIALIZED;
        return innerH(child).__SERIALIZED;
    };
    return tree.map((subtree) => toH(innerH, subtree).__SERIALIZED);
});

==> astro-0.0.8.tgz: package/lib/frontend/render/utils.js <==
import unified from 'unified';
import parse from 'rehype-parse';
import toH from 'hast-to-hyperscript';
import moize from 'moize';
/** @internal */
function childrenToTree(children) {
    return children.map((child) => unified().use(parse, { fragment: true }).parse(child).children.pop());
}
/**
 * Converts an HTML fragment string into vnodes for rendering via provided framework
 * @param h framework's `createElement` function
 * @param children the HTML string children
 */
export const childrenToVnodes = moize.deep(function childrenToVnodes(h, children) {
    const tree = childrenToTree(children);
    const vnodes = tree.map((subtree) => {
        if (subtree.type === 'text')
            return subtree.value;
        return toH(h, subtree);
    });
    return vnodes;
});
/**
 * Converts an HTML fragment string into h function calls as a string
 * @param h framework's `createElement` function
 * @param children the HTML string children
 */
export const childrenToH = moize.deep(function childrenToH(renderer, children) {
    if (!renderer.jsxPragma)
        return;
    const tree = childrenToTree(children);
    const innerH = (name, attrs = null, _children = null) => {
        const vnode = renderer.jsxPragma?.(name, attrs, _children);
        const childStr = _children ? `, [${_children.map((child) => serializeChild(child)).join(',')}]` : '';
        /* fix(react): avoid hard-coding keys into the serialized tree */
        if (attrs && attrs.key)
            attrs.key = undefined;
        const __SERIALIZED = `${renderer.jsxPragmaName}("${name}", ${attrs ? JSON.stringify(attrs) : 'null'}${childStr})`;
        return { ...vnode, __SERIALIZED };
    };
    const serializeChild = (child) => {
        if (['string', 'number', 'boolean'].includes(typeof child))
            return JSON.stringify(child);
        if (child === null)
            return `null`;
        if (child.__SERIALIZED)
            return child.__SERIALIZED;
        return innerH(child).__SERIALIZED;
    };
    return tree.map((subtree) => {
        if (subtree.type === 'text')
            return JSON.stringify(subtree.value);
        return toH(innerH, subtree).__SERIALIZED;
    });
});
